@@ -15,7 +15,9 @@ from .ascii85test import Ascii85test
 from .asuphoenix import Asuphoenix
 from .ax25frames import Ax25frames
 from .ax25monitor import Ax25monitor
+from .azaadisat2 import Azaadisat2
 from .bdsat import Bdsat
+from .bdsat2 import Bdsat2
 from .bisonsat import Bisonsat
 from .bobcat1 import Bobcat1
 from .bugsat1 import Bugsat1
@@ -23,7 +25,10 @@ from .cape1 import Cape1
 from .cas4 import Cas4
 from .cas9 import Cas9
 from .chomptt import Chomptt
+from .cirbe import Cirbe
+from .connectat11 import Connectat11
 from .csim import Csim
+from .ctim import Ctim
 from .cubebel1 import Cubebel1
 from .cubesatsim import Cubesatsim
 from .cute import Cute
@@ -36,9 +41,12 @@ from .elfin import Elfin
 from .entrysat import Entrysat
 from .equisat import Equisat
 from .eshail2 import Eshail2
+from .foresail1 import Foresail1
 from .fox import Fox
 from .gaspacs import Gaspacs
+from .geoscanedelveis import Geoscanedelveis
 from .grbalpha import Grbalpha
+from .greencube import Greencube
 from .grizu263a import Grizu263a
 from .gt1 import Gt1
 from .inspiresat1 import Inspiresat1
@@ -56,10 +64,13 @@ from .mxl import Mxl
 from .mysat import Mysat
 from .netsat import Netsat
 from .neutron1 import Neutron1
+from .nutsat1 import Nutsat1
 from .opssat1 import Opssat1
 from .oresat0 import Oresat0
 from .origamisat1 import Origamisat1
 from .painani import Painani
+from .picsat import Picsat
+from .planetum1 import Planetum1
 from .polyitan1 import Polyitan1
 from .pwsat2 import Pwsat2
 from .qarman import Qarman
@@ -67,12 +78,16 @@ from .qbee import Qbee
 from .qubik import Qubik
 from .quetzal1 import Quetzal1
 from .ramsat import Ramsat
+from .roseycubesat1 import Roseycubesat1
 from .salsat import Salsat
 from .sanosat1 import Sanosat1
+from .selfiesat import Selfiesat
+from .sharjahsat1 import Sharjahsat1
 from .siriussat import Siriussat
 from .skcube import Skcube
 from .spoc import Spoc
 from .strand import Strand
+from .suchai2 import Suchai2
 from .targit import Targit
 from .us6 import Us6
 from .uwe4 import Uwe4
@@ -88,7 +103,9 @@ __all__ = [
     'Asuphoenix',
     'Ax25frames',
     'Ax25monitor',
+    'Azaadisat2',
     'Bdsat',
+    'Bdsat2',
     'Bisonsat',
     'Bobcat1',
     'Bugsat1',
@@ -96,10 +113,13 @@ __all__ = [
     'Cas4',
     'Cas9',
     'Chomptt',
+    'Connectat11',
     'Cubebel1',
     'Cubesatsim',
     'Cute',
     'Csim',
+    'Ctim',
+    'Cirbe',
     'Delfin3xt',
     'Delfipq',
     'Dhabisat',
@@ -109,9 +129,12 @@ __all__ = [
     'Entrysat',
     'Eshail2',
     'Equisat',
+    'Foresail1',
     'Fox',
     'Gaspacs',
+    'Geoscanedelveis',
     'Grbalpha',
+    'Greencube',
     'Grizu263a',
     'Gt1',
     'Inspiresat1',
@@ -129,10 +152,13 @@ __all__ = [
     'Mysat',
     'Netsat',
     'Neutron1',
+    'Nutsat1',
     'Opssat1',
     'Oresat0',
     'Origamisat1',
     'Painani',
+    'Picsat',
+    'Planetum1',
     'Polyitan1',
     'Pwsat2',
     'Qarman',
@@ -140,12 +166,16 @@ __all__ = [
     'Qubik',
     'Quetzal1',
     'Ramsat',
+    'Roseycubesat1',
     'Salsat',
     'Sanosat1',
+    'Selfiesat',
+    'Sharjahsat1',
     'Siriussat',
     'Skcube',
     'Spoc',
     'Strand',
+    'Suchai2',
     'Targit',
     'Us6',
     'Uwe4',
